@@ -1,7 +1,9 @@
 ##################################################################
 ##########     Plot density                  #####################
 mix.dens <- function(y, model, log=FALSE, ylab=NULL, xlab = NULL, main = NULL, ...){
-  if((class(model) != "t") && (class(model) != "Skew.t") && (class(model) != "Skew.cn") && (class(model) != "Skew.slash") && (class(model) != "Skew.normal") && (class(model) != "Normal")) stop(paste("Class of family",class(model),"not recognized.",sep=" "))
+  if(!inherits(model, 't') && !inherits(model, 'Skew.t') && !inherits(model, 'Skew.cn') &&
+     !inherits(model, 'Skew.slash') && !inherits(model, 'Skew.normal') &&
+     !inherits(model, 'Normal')) stop(paste("Class of family",class(model),"not recognized.",sep=" "))
   y <- as.matrix(y) 
   if (dim(y)[2] != 1) stop("The mix.dens function is only appropriate for the univariate analysis.\n")
 
@@ -16,7 +18,7 @@ mix.dens <- function(y, model, log=FALSE, ylab=NULL, xlab = NULL, main = NULL, .
      lim <- -9
 
      xx=seq(min(y),max(y),(max(y)-min(y))/1000)   
-     if ((class(model) == "Skew.t") || class(model) == "t"){
+     if (inherits(model, 'Skew.t') || inherits(model, 't')){
       if(!log) plot(xx,d.mixedST(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu),type="l",ylab=ylab, xlab = xlab, main = main, ...)
       else{
          aux <- log(d.mixedST(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu))
@@ -24,7 +26,7 @@ mix.dens <- function(y, model, log=FALSE, ylab=NULL, xlab = NULL, main = NULL, .
          plot(xx,aux,type="l",ylab=ylab, xlab = xlab, main = main, ...)
 	}
      }
-     if (class(model) == "Skew.cn"){
+     if (inherits(model, 'Skew.cn')){
       if(!log) plot(xx,d.mixedSNC(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu),type="l",ylab=ylab, xlab = xlab, main = main, ...)
       else{
 	 aux <- log(d.mixedSNC(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu))
@@ -32,7 +34,7 @@ mix.dens <- function(y, model, log=FALSE, ylab=NULL, xlab = NULL, main = NULL, .
          plot(xx,aux,type="l",ylab=ylab, xlab = xlab, main = main, ...)
 	}
      }
-     if (class(model) == "Skew.slash"){
+     if (inherits(model, 'Skew.slash')){
       if(!log) plot(xx,d.mixedSS(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu),type="l",ylab=ylab, xlab = xlab, main = main, ...)
       else{
 	 aux <- log(d.mixedSS(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu))
@@ -40,7 +42,7 @@ mix.dens <- function(y, model, log=FALSE, ylab=NULL, xlab = NULL, main = NULL, .
          plot(xx,aux,type="l",ylab=ylab, xlab = xlab, main = main, ...)
 	}
      }
-     if ((class(model) == "Skew.normal") || (class(model) == "Normal")){
+     if (inherits(model, 'Skew.normal') || inherits(model, 'Normal')){
       if(!log) plot(xx,d.mixedSN(xx, model$pii, model$mu, model$sigma2, model$shape),type="l",ylab=ylab, xlab = xlab, main = main, ...)
       else{
 	 aux <- log(d.mixedSN(xx, model$pii, model$mu, model$sigma2, model$shape))
@@ -53,14 +55,16 @@ mix.dens <- function(y, model, log=FALSE, ylab=NULL, xlab = NULL, main = NULL, .
 ##########     Lines	                     #####################
 
 mix.lines <- function(y, model, log=FALSE, ...){
-  if((class(model) != "t") && (class(model) != "Skew.t") && (class(model) != "Skew.cn") && (class(model) != "Skew.slash") && (class(model) != "Skew.normal") && (class(model) != "Normal")) stop(paste("Class of family",class(model),"not recognized.",sep=" "))
+  if(!inherits(model, 't') && !inherits(model, 'Skew.t') && !inherits(model, 'Skew.cn') &&
+     !inherits(model, 'Skew.slash') && !inherits(model, 'Skew.normal') &&
+     !inherits(model, 'Normal')) stop(paste("Class of family",class(model),"not recognized.",sep=" "))
   y <- as.matrix(y) 
   if (dim(y)[2] != 1) stop("The mix.dens function is only appropriate for the univariate analysis.\n")
 
      lim <- -9
      xx=seq(min(y),max(y),(max(y)-min(y))/1000)   
 
-     if ((class(model) == "Skew.t") || class(model) == "t"){
+     if (inherits(model, 'Skew.t') || inherits(model, 't')){
       if(!log) lines(xx,d.mixedST(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu), ...)
       else{
          aux <- log(d.mixedST(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu))
@@ -68,7 +72,7 @@ mix.lines <- function(y, model, log=FALSE, ...){
          lines(xx,aux,...)
 	}
      }
-     if (class(model) == "Skew.cn"){
+     if (inherits(model, 'Skew.cn')){
       if(!log) lines(xx,d.mixedSNC(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu),...)
       else{
 	 aux <- log(d.mixedSNC(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu))
@@ -76,7 +80,7 @@ mix.lines <- function(y, model, log=FALSE, ...){
          lines(xx,aux,...)
 	}
      }
-     if (class(model) == "Skew.slash"){
+     if (inherits(model, 'Skew.slash')){
       if(!log) lines(xx,d.mixedSS(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu),...)
       else{
 	 aux <- log(d.mixedSS(xx, model$pii, model$mu, model$sigma2, model$shape, model$nu))
@@ -84,7 +88,7 @@ mix.lines <- function(y, model, log=FALSE, ...){
          lines(xx,aux,...)
 	}
      }
-     if ((class(model) == "Skew.normal") || (class(model) == "Normal")){
+     if (inherits(model, 'Skew.normal') || inherits(model, 'Normal')){
       if(!log) lines(xx,d.mixedSN(xx, model$pii, model$mu, model$sigma2, model$shape),...)
       else{
 	 aux <- log(d.mixedSN(xx, model$pii, model$mu, model$sigma2, model$shape))
